pub type Micros = u128;Expand description
One millionth of a currency unit, which is the precision
ingot_ir::format_amount already renders.
pub type Micros = u128;One millionth of a currency unit, which is the precision
ingot_ir::format_amount already renders.