pub enum ResponseShape {
Prose,
FreeJson,
Schema {
schema: Value,
wrapped: bool,
},
}Expand description
How a declared response type is requested from a provider.
Variants
Prose
Take the completion text verbatim. Used for text and markdown.
FreeJson
Parse the completion as JSON without constraining it. Used for json,
which by definition has no fixed shape to constrain to.
Schema
Constrain the completion to a schema.