pub fn response_shape(
ty: &str,
types: &BTreeMap<String, RecordType>,
) -> Result<ResponseShape, UnsupportedResponseType>Expand description
Work out how to request ty, resolving record types against types.
pub fn response_shape(
ty: &str,
types: &BTreeMap<String, RecordType>,
) -> Result<ResponseShape, UnsupportedResponseType>Work out how to request ty, resolving record types against types.