pub enum ConsultError {
NoChannel(String),
Failed(String),
NotAChoice {
answer: String,
choices: Vec<String>,
},
}Expand description
Why a question could not be answered.
Variants
NoChannel(String)
There is nobody to ask.
Failed(String)
Somebody was asked and the answer did not arrive.
NotAChoice
An answer arrived that was not one of the choices offered.